@@ -2,27 +2,28 @@
 {
 require(tcltk) || stop("tcltk support is absent")
     if (!exists("slider.env")) 
-        slider.env <<- new.env()
+        slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
 
     r <- 1
     p <- 0.5
-    assign("r", tclVar(r), env = slider.env)  
-    assign("p", tclVar(p), env = slider.env)           
+    assign("r", tclVar(r), envir= slider.env)  
+    assign("p", tclVar(p), envir= slider.env)           
     xmin <- 0
-    assign("xmin", tclVar(xmin), env = slider.env)
+    assign("xmin", tclVar(xmin), envir= slider.env)
     xmax <- 20
-    assign("xmax", tclVar(xmax), env = slider.env)
+    assign("xmax", tclVar(xmax), envir= slider.env)
    
      norm.refresh <- function(...) {
-        r <- as.numeric(evalq(tclvalue(r), env = slider.env))
-        p <- as.numeric(evalq(tclvalue(p), env = slider.env))
-        xmin <- as.numeric(evalq(tclvalue(xmin), env = slider.env))
-        xmax <- as.numeric(evalq(tclvalue(xmax), env = slider.env))
+        r <- as.numeric(evalq(tclvalue(r), envir= slider.env))
+        p <- as.numeric(evalq(tclvalue(p), envir= slider.env))
+        xmin <- as.numeric(evalq(tclvalue(xmin), envir= slider.env))
+        xmax <- as.numeric(evalq(tclvalue(xmax), envir= slider.env))
         xx <- seq(xmin, xmax)
         yy <- dnbinom(xx,r,p)
    
         plot(xx, yy, type = "h", ylab = "f(x)", xlab = "x")
         points(xx, yy, pch =19)
+        dev.flush()
                     }
     
     m <- tktoplevel()
@@ -36,8 +37,8 @@ require(tcltk) || stop("tcltk support is absent")
     tkpack(sc <- tkscale(fr, command = norm.refresh, from = 1, 
         to = 20, orient = "horiz", resolution = 1, showvalue = TRUE), 
         side = "left")
-    assign("sc", sc, env = slider.env)
-    evalq(tkconfigure(sc, variable = r), env = slider.env)  
+    assign("sc", sc, envir= slider.env)
+    evalq(tkconfigure(sc, variable = r), envir= slider.env)  
     
     tkpack(fr <- tkframe(m), side = "top")
     tkpack(tklabel(fr, text = "p", font=c("Helvetica","9","italic"),width = "20"), 
@@ -45,18 +46,18 @@ require(tcltk) || stop("tcltk support is absent")
     tkpack(sc <- tkscale(fr, command = norm.refresh, from = 0.01, 
         to = 1, orient = "horiz", resolution = 0.01, showvalue = TRUE), 
         side = "left")
-    assign("sc", sc, env = slider.env)
-    evalq(tkconfigure(sc, variable = p), env = slider.env)  
+    assign("sc", sc, envir= slider.env)
+    evalq(tkconfigure(sc, variable = p), envir= slider.env)  
 
  tkpack(fr <- tkframe(m), side = "top")
     tkpack(tklabel(fr, text = "Xmin:", width = 6), side = "left")
     tkpack(e <- tkentry(fr, width = 8), side = "left")
-    assign("e", e, env = slider.env)
-    evalq(tkconfigure(e, textvariable = xmin), env = slider.env)
+    assign("e", e, envir= slider.env)
+    evalq(tkconfigure(e, textvariable = xmin), envir= slider.env)
     tkpack(tklabel(fr, text = "Xmax:", width = 6), side = "left")
     tkpack(e <- tkentry(fr, width = 8), side = "left")
-    assign("e", e, env = slider.env)
-    evalq(tkconfigure(e, textvariable = xmax), env = slider.env)
+    assign("e", e, envir= slider.env)
+    evalq(tkconfigure(e, textvariable = xmax), envir= slider.env)
     tkpack(tkbutton(m, text = "Refresh", command = norm.refresh), 
         side = "left")
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
@@ -68,23 +69,23 @@ require(tcltk) || stop("tcltk support is absent")
 {
 require(tcltk) || stop("tcltk support is absent")
     if (!exists("slider.env")) 
-        slider.env <<- new.env()
+        slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
 
     r <- 1
     p <- 0.5
-    assign("r", tclVar(r), env = slider.env)  
-    assign("p", tclVar(p), env = slider.env)           
+    assign("r", tclVar(r), envir= slider.env)  
+    assign("p", tclVar(p), envir= slider.env)           
     xmin <- 0
-    assign("xmin", tclVar(xmin), env = slider.env)
+    assign("xmin", tclVar(xmin), envir= slider.env)
     xmax <- 20
-    assign("xmax", tclVar(xmax), env = slider.env)
+    assign("xmax", tclVar(xmax), envir= slider.env)
        
     dev.new(height=4,width=8);par(mfrow=c(1,2),mar=c(4.4,4.5,1,0.5),cex=.85);layout(matrix(c(1,2), 1, 2, byrow = TRUE))   
     norm.refresh <- function(...) {
-        r <- as.numeric(evalq(tclvalue(r), env = slider.env))
-        p <- as.numeric(evalq(tclvalue(p), env = slider.env))
-        xmin <- as.numeric(evalq(tclvalue(xmin), env = slider.env))
-        xmax <- as.numeric(evalq(tclvalue(xmax), env = slider.env))
+        r <- as.numeric(evalq(tclvalue(r), envir= slider.env))
+        p <- as.numeric(evalq(tclvalue(p), envir= slider.env))
+        xmin <- as.numeric(evalq(tclvalue(xmin), envir= slider.env))
+        xmax <- as.numeric(evalq(tclvalue(xmax), envir= slider.env))
         xx <- seq(xmin, xmax)
         yy <- dnbinom(xx,r,p)
         y1 <- pnbinom(xx,r,p)
@@ -94,7 +95,7 @@ require(tcltk) || stop("tcltk support is absent")
         points(xx, y1, pch =19)
         segments(xx, y1,xx+1,y1)
         points(xx+1, y1, pch =1)
-        
+        dev.flush()
                     }
     m <- tktoplevel()
     tkwm.title(m, "Visualizing the Negative Binomial Distribution")
@@ -107,8 +108,8 @@ require(tcltk) || stop("tcltk support is absent")
     tkpack(sc <- tkscale(fr, command = norm.refresh, from = 1, 
         to = 20, orient = "horiz", resolution = 1, showvalue = TRUE), 
         side = "left")
-    assign("sc", sc, env = slider.env)
-    evalq(tkconfigure(sc, variable = r), env = slider.env)  
+    assign("sc", sc, envir= slider.env)
+    evalq(tkconfigure(sc, variable = r), envir= slider.env)  
     
     tkpack(fr <- tkframe(m), side = "top")
     tkpack(tklabel(fr, text = "p", font=c("Helvetica","9","italic"),width = "20"), 
@@ -116,18 +117,18 @@ require(tcltk) || stop("tcltk support is absent")
     tkpack(sc <- tkscale(fr, command = norm.refresh, from = 0.01, 
         to = 1, orient = "horiz", resolution = 0.01, showvalue = TRUE), 
         side = "left")
-    assign("sc", sc, env = slider.env)
-    evalq(tkconfigure(sc, variable = p), env = slider.env)  
+    assign("sc", sc, envir= slider.env)
+    evalq(tkconfigure(sc, variable = p), envir= slider.env)  
 
     tkpack(fr <- tkframe(m), side = "top")
     tkpack(tklabel(fr, text = "Xmin:", width = 6), side = "left")
     tkpack(e <- tkentry(fr, width = 8), side = "left")
-    assign("e", e, env = slider.env)
-    evalq(tkconfigure(e, textvariable = xmin), env = slider.env)
+    assign("e", e, envir= slider.env)
+    evalq(tkconfigure(e, textvariable = xmin), envir= slider.env)
     tkpack(tklabel(fr, text = "Xmax:", width = 6), side = "left")
     tkpack(e <- tkentry(fr, width = 8), side = "left")
-    assign("e", e, env = slider.env)
-    evalq(tkconfigure(e, textvariable = xmax), env = slider.env)
+    assign("e", e, envir= slider.env)
+    evalq(tkconfigure(e, textvariable = xmax), envir= slider.env)
     tkpack(tkbutton(m, text = "Refresh", command = norm.refresh), 
         side = "left")
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
