@@ -1,26 +1,28 @@
 see.weib.tck<-function () 
 {
 require(tcltk) || stop("tcltk support is absent")
+tclServiceMode(TRUE)
     if (!exists("slider.env")) 
-        slider.env <<- new.env()
+        slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
     theta <- 1
     beta<-1
-    assign("theta", tclVar(theta), env = slider.env)
-    assign("beta", tclVar(beta), env = slider.env)
+    assign("theta", tclVar(theta), envir = slider.env)
+    assign("beta", tclVar(beta), envir = slider.env)
     xmin <- 0
-    assign("xmin", tclVar(xmin), env = slider.env)
+    assign("xmin", tclVar(xmin), envir = slider.env)
     xmax <- 30
-    assign("xmax", tclVar(xmax), env = slider.env)
+    assign("xmax", tclVar(xmax), envir = slider.env)
            
    norm.refresh <- function(...) {
-        theta <- as.numeric(evalq(tclvalue(theta), env = slider.env))
-        beta <- as.numeric(evalq(tclvalue(beta), env = slider.env))
-        xmin <- as.numeric(evalq(tclvalue(xmin), env = slider.env))
-        xmax <- as.numeric(evalq(tclvalue(xmax), env = slider.env))
+        theta <- as.numeric(evalq(tclvalue(theta), envir = slider.env))
+        beta <- as.numeric(evalq(tclvalue(beta), envir = slider.env))
+        xmin <- as.numeric(evalq(tclvalue(xmin), envir = slider.env))
+        xmax <- as.numeric(evalq(tclvalue(xmax), envir = slider.env))
         xx <- seq(xmin, xmax, length = 500)
         yy <- dweibull(xx, theta, beta)
-        
+        dev.hold()
         plot(xx, yy, type = "l", xlim = c(xmin, xmax), ylab = "f(x)", xlab = "x")
+        dev.flush()          
                     }
     m <- tktoplevel()
   tkwm.title(m, "Visualizing the Weibull Distribution")
@@ -33,26 +35,26 @@ require(tcltk) || stop("tcltk support is absent")
     tkpack(sc <- tkscale(fr, command = norm.refresh, from = 0.1, 
         to = 15, orient = "horiz", resolution = 0.1, showvalue = TRUE), 
         side = "left")
-    assign("sc", sc, env = slider.env)
-    evalq(tkconfigure(sc, variable = theta), env = slider.env)
+    assign("sc", sc, envir = slider.env)
+    evalq(tkconfigure(sc, variable = theta), envir = slider.env)
     
     tkpack(fr <- tkframe(m), side = "top")
     tkpack(tklabel(fr, text = '\u03b2',font=c("Helvetica","9","italic"), width = "20"), side = "right")
     tkpack(sc <- tkscale(fr, command = norm.refresh, from = 0.1, 
         to = 15, orient = "horiz", resolution = 0.1, showvalue = TRUE), 
         side = "left")
-    assign("sc", sc, env = slider.env)
-    evalq(tkconfigure(sc, variable = beta), env = slider.env)
+    assign("sc", sc, envir = slider.env)
+    evalq(tkconfigure(sc, variable = beta), envir = slider.env)
     
     tkpack(fr <- tkframe(m), side = "top")
     tkpack(tklabel(fr, text = "Xmin:", width = 6), side = "left")
     tkpack(e <- tkentry(fr, width = 8), side = "left")
-    assign("e", e, env = slider.env)
-    evalq(tkconfigure(e, textvariable = xmin), env = slider.env)
+    assign("e", e, envir = slider.env)
+    evalq(tkconfigure(e, textvariable = xmin), envir = slider.env)
     tkpack(tklabel(fr, text = "Xmax:", width = 6), side = "left")
     tkpack(e <- tkentry(fr, width = 8), side = "left")
-    assign("e", e, env = slider.env)
-    evalq(tkconfigure(e, textvariable = xmax), env = slider.env)
+    assign("e", e, envir = slider.env)
+    evalq(tkconfigure(e, textvariable = xmax), envir = slider.env)
     tkpack(tkbutton(m, text = "Refresh", command = norm.refresh), 
         side = "left")
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
@@ -63,28 +65,31 @@ require(tcltk) || stop("tcltk support is absent")
 
 see.weibcdf.tck<-function (){ 
 require(tcltk) || stop("tcltk support is absent")
+tclServiceMode(TRUE)
     if (!exists("slider.env")) 
-        slider.env <<- new.env()
+        slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
     theta <- 1
     beta<-1
-    assign("theta", tclVar(theta), env = slider.env)
-    assign("beta", tclVar(beta), env = slider.env)
+    assign("theta", tclVar(theta), envir = slider.env)
+    assign("beta", tclVar(beta), envir = slider.env)
     xmin <- 0
-    assign("xmin", tclVar(xmin), env = slider.env)
+    assign("xmin", tclVar(xmin), envir = slider.env)
     xmax <- 30
-    assign("xmax", tclVar(xmax), env = slider.env)
+    assign("xmax", tclVar(xmax), envir = slider.env)
            
    dev.new(height=4,width=8);par(mfrow=c(1,2),mar=c(4.4,4.5,1,0.5),cex=.85);layout(matrix(c(1,2), 1, 2, byrow = TRUE))
    norm.refresh <- function(...) {
-        theta <- as.numeric(evalq(tclvalue(theta), env = slider.env))
-        beta <- as.numeric(evalq(tclvalue(beta), env = slider.env))
-        xmin <- as.numeric(evalq(tclvalue(xmin), env = slider.env))
-        xmax <- as.numeric(evalq(tclvalue(xmax), env = slider.env))
+        theta <- as.numeric(evalq(tclvalue(theta), envir = slider.env))
+        beta <- as.numeric(evalq(tclvalue(beta), envir = slider.env))
+        xmin <- as.numeric(evalq(tclvalue(xmin), envir = slider.env))
+        xmax <- as.numeric(evalq(tclvalue(xmax), envir = slider.env))
         xx <- seq(xmin, xmax, length = 500)
         yy <- dweibull(xx, theta, beta)
         y1<- pweibull(xx, theta, beta)
+        dev.hold()
         plot(xx, yy, type = "l", xlim = c(xmin, xmax), ylab = "f(x)", xlab = "x")
         plot(xx, y1, type = "l", xlim = c(xmin, xmax), ylab = "F(x)", xlab = "x")
+        dev.flush()          
                     }
     m <- tktoplevel()
   tkwm.title(m, "Visualizing the Weibull Distribution")
@@ -97,26 +102,26 @@ require(tcltk) || stop("tcltk support is absent")
     tkpack(sc <- tkscale(fr, command = norm.refresh, from = 0.1, 
         to = 15, orient = "horiz", resolution = 0.1, showvalue = TRUE), 
         side = "left")
-    assign("sc", sc, env = slider.env)
-    evalq(tkconfigure(sc, variable = theta), env = slider.env)
+    assign("sc", sc, envir = slider.env)
+    evalq(tkconfigure(sc, variable = theta), envir = slider.env)
     
     tkpack(fr <- tkframe(m), side = "top")
     tkpack(tklabel(fr, text = '\u03b2',font=c("Helvetica","9","italic"), width = "20"), side = "right")
     tkpack(sc <- tkscale(fr, command = norm.refresh, from = 0.1, 
         to = 15, orient = "horiz", resolution = 0.1, showvalue = TRUE), 
         side = "left")
-    assign("sc", sc, env = slider.env)
-    evalq(tkconfigure(sc, variable = beta), env = slider.env)
+    assign("sc", sc, envir = slider.env)
+    evalq(tkconfigure(sc, variable = beta), envir = slider.env)
     
     tkpack(fr <- tkframe(m), side = "top")
     tkpack(tklabel(fr, text = "Xmin:", width = 6), side = "left")
     tkpack(e <- tkentry(fr, width = 8), side = "left")
-    assign("e", e, env = slider.env)
-    evalq(tkconfigure(e, textvariable = xmin), env = slider.env)
+    assign("e", e, envir = slider.env)
+    evalq(tkconfigure(e, textvariable = xmin), envir = slider.env)
     tkpack(tklabel(fr, text = "Xmax:", width = 6), side = "left")
     tkpack(e <- tkentry(fr, width = 8), side = "left")
-    assign("e", e, env = slider.env)
-    evalq(tkconfigure(e, textvariable = xmax), env = slider.env)
+    assign("e", e, envir = slider.env)
+    evalq(tkconfigure(e, textvariable = xmax), envir = slider.env)
     tkpack(tkbutton(m, text = "Refresh", command = norm.refresh), 
         side = "left")
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
